@@ -2,6 +2,8 @@ import cv2
 import numpy as np
 from math import sin, cos, atan, degrees
 import matplotlib.pyplot as plt
+import xml.etree.ElementTree as ET
+
 from .Point_class import Point
 from .Line_class import Line
 from .BoundBox_utils import min_value, max_value
@@ -44,6 +46,9 @@ class BoundBox:
         # self._length = None
         # self._breadth = None
 
+    def to_dict(self):
+        return {'p1': self._p1, 'p2': self._p2, 'p3': self._p3, 'p4': self._p4, 'text': self.text_value}
+
     def sort_points(self):
         """
         sort the points of the box after transformations
@@ -214,7 +219,7 @@ class BoundBox:
         try:
             for i in range(len(data['level'])):
 
-                if data['text'][i]:
+                #if data['text'][i]:
                     (x, y, w, h) = (data['left'][i], data['top'][i], data['width'][i], data['height'][i])
                     corner_1 = Point(x, y)
                     corner_2 = Point(x+w, y+h)
@@ -229,6 +234,64 @@ class BoundBox:
 
         return box_list
 
+    @classmethod
+    def google_ocr_boxes(cls, data):
+        """
+        create a list of list of boxes from results from google ocr data
+        here the result is a list of list because multiple pages can be parsed together
+        and a list of boxes is created for each page
+        :param data: google ocr response data as dict
+        :return: list(list(boxes))
+        """
+
+        page_list = []
+        google_response = data['responses']
+
+        # fill zero values for places where google ocr omitted values
+        for page in google_response:
+            for annotation in page['textAnnotations']:
+                for vertex in range(len(annotation['boundingPoly']['vertices'])):
+                    if 'x' not in annotation['boundingPoly']['vertices'][vertex]:
+                        annotation['boundingPoly']['vertices'][vertex]['x'] = 0
+
+                    elif 'y' not in annotation['boundingPoly']['vertices'][vertex]:
+                        annotation['boundingPoly']['vertices'][vertex]['y'] = 0
+
+        for page in google_response:
+            box_list = []
+            text_annotations = page['textAnnotations'][1:]
+
+            for annotation in text_annotations:
+                box = cls.create_box(annotation['boundingPoly']['vertices'][0]['x'],
+                                     annotation['boundingPoly']['vertices'][0]['y'],
+                                     annotation['boundingPoly']['vertices'][1]['x'],
+                                     annotation['boundingPoly']['vertices'][1]['y'],
+                                     annotation['boundingPoly']['vertices'][2]['x'],
+                                     annotation['boundingPoly']['vertices'][2]['y'],
+                                     annotation['boundingPoly']['vertices'][3]['x'],
+                                     annotation['boundingPoly']['vertices'][3]['y'],
+                                     annotation['description'])
+                box_list.append(box)
+            page_list.append(box_list)
+
+        return page_list
+
+    @classmethod
+    def labelimg_xml_boxes(cls, xml_path):
+        tree = ET.parse(xml_path)
+        root = tree.getroot()
+
+        box_list = []
+
+        for member in root.findall('object'):
+            text = member[0].text
+            corner_1 = Point(int(member[4][0].text), int(member[4][1].text))
+            corner_2 = Point(int(member[4][2].text), int(member[4][3].text))
+            box = cls.create_box_from_corners(corner_1, corner_2, text_value=text)
+            box_list.append(box)
+
+        return box_list
+
     @classmethod
     def box_from_contour(cls, countour):
         if len(countour) != 4:
@@ -391,6 +454,9 @@ class BoundBox:
         points = np.array([[self._p1.x, self._p1.y], [self._p2.x, self._p2.y], [self._p3.x, self._p3.y],
                            [self._p4.x, self._p4.y]])
         cv2.polylines(img, np.int32([points]), True, (0, 255, 0), thickness=3)
+        cv2.putText(img, self.text_value, (self.p1.x, self.p1.y-5), cv2.FONT_HERSHEY_SIMPLEX, 0.5,
+                    (0, 0, 255), 1)
+
         return img
 
     @property
